@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005,
-              2006, 2007 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,10 +34,15 @@ LSODE : public ODE, public LSODE_options
 {
 public:
 
-  LSODE (void) : ODE (), LSODE_options (), initialized (false) { }
+  LSODE (void)
+    : ODE (), LSODE_options (), initialized (false), method_flag (0),
+      maxord (0), itask (0), iopt (0), itol (0), liw (0), lrw (0),
+      iwork (), rwork (), rel_tol (0.0), abs_tol () { }
 
   LSODE (const ColumnVector& s, double tm, const ODEFunc& f)
-    : ODE (s, tm, f), LSODE_options (), initialized (false) { }
+    : ODE (s, tm, f), LSODE_options (), initialized (false), method_flag (0),
+      maxord (0), itask (0), iopt (0), itol (0), liw (0), lrw (0),
+      iwork (), rwork (), rel_tol (0.0), abs_tol () { }
 
   ~LSODE (void) { }
 
@@ -69,17 +73,6 @@ private:
   double rel_tol;
 
   Array<double> abs_tol;
-
-  double *px;
-  double *pabs_tol;
-  octave_idx_type *piwork;
-  double *prwork;
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
