@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 1994, 1995, 1996, 1997, 2002, 2003, 2004, 2005, 2007,
-              2008, 2009 John W. Eaton
+Copyright (C) 1994-2011 John W. Eaton
+Copyright (C) 2009 VZLU Prague
 
 This file is part of Octave.
 
@@ -35,23 +35,24 @@ along with Octave; see the file COPYING.  If not, see
 extern "C"
 {
   F77_RET_T
-  F77_FUNC (dgeqp3, DGEQP3) (const octave_idx_type&, const octave_idx_type&, double*,
-			     const octave_idx_type&, octave_idx_type*, double*, double*,
+  F77_FUNC (dgeqp3, DGEQP3) (const octave_idx_type&, const octave_idx_type&,
+                             double*, const octave_idx_type&,
+                             octave_idx_type*, double*, double*,
                              const octave_idx_type&, octave_idx_type&);
 }
 
 // It would be best to share some of this code with QR class...
 
-QRP::QRP (const Matrix& a, QR::type qr_type)
+QRP::QRP (const Matrix& a, qr_type_t qr_type)
   : QR (), p ()
 {
   init (a, qr_type);
 }
 
 void
-QRP::init (const Matrix& a, QR::type qr_type)
+QRP::init (const Matrix& a, qr_type_t qr_type)
 {
-  assert (qr_type != QR::raw);
+  assert (qr_type != qr_type_raw);
 
   octave_idx_type m = a.rows ();
   octave_idx_type n = a.cols ();
@@ -62,10 +63,10 @@ QRP::init (const Matrix& a, QR::type qr_type)
   octave_idx_type info = 0;
 
   Matrix afact = a;
-  if (m > n && qr_type == QR::std)
+  if (m > n && qr_type == qr_type_std)
     afact.resize (m, m);
 
-  MArray<octave_idx_type> jpvt (n, 0);
+  MArray<octave_idx_type> jpvt (dim_vector (n, 1), 0);
 
   if (m > 0)
     {
@@ -94,16 +95,10 @@ QRP::init (const Matrix& a, QR::type qr_type)
   form (n, afact, tau, qr_type);
 }
 
-ColumnVector
+RowVector
 QRP::Pvec (void) const
 {
   Array<double> pa (p.pvec ());
-  ColumnVector pv (MArray<double> (pa) + 1.0);
+  RowVector pv (MArray<double> (pa) + 1.0);
   return pv;
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
