@@ -1,5 +1,6 @@
 /*
-Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009 David Bateman
+Copyright (C) 2003-2011 David Bateman
+Copyright (C) 2009-2010 VZLU Prague
 
 This file is part of Octave.
 
@@ -24,7 +25,7 @@ code I ripped-off.
 As required in the Python license the short description of the changes
 made are
 
-* convert the sorting code in listobject.cc into a generic class, 
+* convert the sorting code in listobject.cc into a generic class,
   replacing PyObject* with the type of the class T.
 
 The Python license is
@@ -108,13 +109,13 @@ octave_sort
 public:
 
   typedef bool (*compare_fcn_type) (typename ref_param<T>::type,
-				    typename ref_param<T>::type);
+                                    typename ref_param<T>::type);
 
   octave_sort (void);
 
   octave_sort (compare_fcn_type);
-  
-  ~octave_sort (void); 
+
+  ~octave_sort (void);
 
   void set_compare (compare_fcn_type comp) { compare = comp; }
 
@@ -135,24 +136,34 @@ public:
                   octave_idx_type rows, octave_idx_type cols);
 
   // Determine whether a matrix (as a contiguous block) is sorted by rows.
-  bool is_sorted_rows (const T *data, 
+  bool is_sorted_rows (const T *data,
                        octave_idx_type rows, octave_idx_type cols);
 
   // Do a binary lookup in a sorted array.
   octave_idx_type lookup (const T *data, octave_idx_type nel,
                           const T& value);
 
-  // Ditto, but for an array of values, specializing on long runs.
-  // Adds offset to all indices.
+  // Ditto, but for an array.
   void lookup (const T *data, octave_idx_type nel,
                const T* values, octave_idx_type nvalues,
-               octave_idx_type *idx, octave_idx_type offset = 0);
+               octave_idx_type *idx);
+
+  // A linear merge of two sorted tables. rev indicates the second table is
+  // in reverse order.
+  void lookup_sorted (const T *data, octave_idx_type nel,
+                      const T* values, octave_idx_type nvalues,
+                      octave_idx_type *idx, bool rev = false);
+
+  // Rearranges the array so that the elements with indices
+  // lo..up-1 are in their correct place.
+  void nth_element (T *data, octave_idx_type nel,
+                    octave_idx_type lo, octave_idx_type up = -1);
 
   static bool ascending_compare (typename ref_param<T>::type,
-				 typename ref_param<T>::type);
+                                 typename ref_param<T>::type);
 
   static bool descending_compare (typename ref_param<T>::type,
-				  typename ref_param<T>::type);
+                                  typename ref_param<T>::type);
 
 private:
 
@@ -163,22 +174,22 @@ private:
   // DGB: This isn't needed with mergesort in a class, but it doesn't
   // slow things up, and it is likely to make my life easier for any
   // potential backporting of changes in the Python code.
-  
-  struct s_slice 
+
+  struct s_slice
   {
     octave_idx_type base, len;
   };
-  
-  struct MergeState 
+
+  struct MergeState
   {
-    MergeState (void) 
-      : a (0), ia (0), alloced (0) 
+    MergeState (void)
+      : min_gallop (), a (0), ia (0), alloced (0), n (0)
       { reset (); }
-    
-    ~MergeState (void) 
+
+    ~MergeState (void)
       { delete [] a; delete [] ia; }
-    
-    void reset (void) 
+
+    void reset (void)
       { min_gallop = MIN_GALLOP; n = 0; }
 
     void getmem (octave_idx_type need);
@@ -196,7 +207,7 @@ private:
     T *a;               // may point to temparray below
     octave_idx_type *ia;
     octave_idx_type alloced;
-    
+
     // A stack of n pending runs yet to be merged.  Run #i starts at
     // address base[i] and extends for len[i] elements.  It's always
     // true (so long as the indices are in bounds) that
@@ -207,21 +218,27 @@ private:
     // and keeping all the info explicit simplifies the code.
     octave_idx_type n;
     struct s_slice pending[MAX_MERGE_PENDING];
+
+    // No copying!
+
+    MergeState (const MergeState&);
+
+    MergeState& operator = (const MergeState&);
   };
 
   compare_fcn_type compare;
-  
+
   MergeState *ms;
-  
-    
+
+
   template <class Comp>
-  void binarysort (T *data, octave_idx_type nel, 
+  void binarysort (T *data, octave_idx_type nel,
               octave_idx_type start, Comp comp);
-    
+
   template <class Comp>
-  void binarysort (T *data, octave_idx_type *idx, octave_idx_type nel, 
+  void binarysort (T *data, octave_idx_type *idx, octave_idx_type nel,
               octave_idx_type start, Comp comp);
-    
+
   template <class Comp>
   octave_idx_type count_run (T *lo, octave_idx_type n, bool& descending, Comp comp);
 
@@ -234,22 +251,22 @@ private:
                                 Comp comp);
 
   template <class Comp>
-  int merge_lo (T *pa, octave_idx_type na, 
+  int merge_lo (T *pa, octave_idx_type na,
                 T *pb, octave_idx_type nb,
                 Comp comp);
 
   template <class Comp>
-  int merge_lo (T *pa, octave_idx_type *ipa, octave_idx_type na, 
+  int merge_lo (T *pa, octave_idx_type *ipa, octave_idx_type na,
                 T *pb, octave_idx_type *ipb, octave_idx_type nb,
                 Comp comp);
 
   template <class Comp>
-  int merge_hi (T *pa, octave_idx_type na, 
+  int merge_hi (T *pa, octave_idx_type na,
                 T *pb, octave_idx_type nb,
                 Comp comp);
 
   template <class Comp>
-  int merge_hi (T *pa, octave_idx_type *ipa, octave_idx_type na, 
+  int merge_hi (T *pa, octave_idx_type *ipa, octave_idx_type na,
                 T *pb, octave_idx_type *ipb, octave_idx_type nb,
                 Comp comp);
 
@@ -290,7 +307,7 @@ private:
                   Comp comp);
 
   template <class Comp>
-  bool is_sorted_rows (const T *data, octave_idx_type rows, 
+  bool is_sorted_rows (const T *data, octave_idx_type rows,
                        octave_idx_type cols, Comp comp);
 
   template <class Comp>
@@ -300,8 +317,23 @@ private:
   template <class Comp>
   void lookup (const T *data, octave_idx_type nel,
                const T* values, octave_idx_type nvalues,
-               octave_idx_type *idx, octave_idx_type offset, Comp comp);
+               octave_idx_type *idx, Comp comp);
 
+  template <class Comp>
+  void lookup_sorted (const T *data, octave_idx_type nel,
+                      const T* values, octave_idx_type nvalues,
+                      octave_idx_type *idx, bool rev, Comp comp);
+
+  template <class Comp>
+  void nth_element (T *data, octave_idx_type nel,
+                    octave_idx_type lo, octave_idx_type up,
+                    Comp comp);
+
+  // No copying!
+
+  octave_sort (const octave_sort&);
+
+  octave_sort& operator = (const octave_sort&);
 };
 
 template <class T>
@@ -313,9 +345,3 @@ public:
   octave_idx_type indx;
 };
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
