@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -30,17 +29,10 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 #include <string.h>
 
-#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#endif
-
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif
 
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#endif
 
 // We can't use csignal as kill is not in the std namespace, and picky
 // compiler runtimes will also exclude it from global scope as well.
@@ -70,13 +62,10 @@ octave_syscalls::dup2 (int old_fd, int new_fd, std::string& msg)
   int status = -1;
 
 #if defined (HAVE_DUP2)
-  status = ::dup2 (old_fd, new_fd);
+  status = gnulib::dup2 (old_fd, new_fd);
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("dup2");
 #endif
@@ -93,7 +82,7 @@ octave_syscalls::execvp (const std::string& file, const string_vector& argv)
 
 int
 octave_syscalls::execvp (const std::string& file, const string_vector& args,
-			 std::string& msg)
+                         std::string& msg)
 {
   msg = std::string ();
 
@@ -107,10 +96,7 @@ octave_syscalls::execvp (const std::string& file, const string_vector& args,
   string_vector::delete_c_str_vec (argv);
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("execvp");
 #endif
@@ -118,35 +104,6 @@ octave_syscalls::execvp (const std::string& file, const string_vector& args,
   return status;
 }
 
-int
-octave_syscalls::fcntl (int fd, int cmd, long arg)
-{
-  std::string msg;
-  return fcntl (fd, cmd, arg, msg);
-}
-
-int
-octave_syscalls::fcntl (int fd, int cmd, long arg, std::string& msg)
-{
-  msg = std::string ();
-
-  int status = -1;
-
-#if defined (HAVE_FCNTL)
-  status = ::fcntl (fd, cmd, arg);
-
-  if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
-#else
-  msg = NOT_SUPPORTED ("fcntl");
-#endif
-
-  return status;
-}
-
 pid_t
 octave_syscalls::fork (std::string& msg)
 {
@@ -156,10 +113,7 @@ octave_syscalls::fork (std::string& msg)
   status = ::fork ();
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("fork");
 #endif
@@ -180,10 +134,7 @@ octave_syscalls::vfork (std::string& msg)
 #endif
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("vfork");
 #endif
@@ -200,10 +151,7 @@ octave_syscalls::getpgrp (std::string& msg)
   status = ::getpgrp ();
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("getpgrp");
 #endif
@@ -289,10 +237,7 @@ octave_syscalls::pipe (int *fildes, std::string& msg)
   status = ::pipe (fildes);
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("pipe");
 #endif
@@ -309,7 +254,7 @@ octave_syscalls::waitpid (pid_t pid, int *status, int options)
 
 pid_t
 octave_syscalls::waitpid (pid_t pid, int *status, int options,
-			  std::string& msg)
+                          std::string& msg)
 {
   pid_t retval = -1;
   msg = std::string ();
@@ -318,10 +263,7 @@ octave_syscalls::waitpid (pid_t pid, int *status, int options,
   retval = ::octave_waitpid (pid, status, options);
 
   if (retval < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("waitpid");
 #endif
@@ -347,10 +289,7 @@ octave_syscalls::kill (pid_t pid, int sig, std::string& msg)
   status = ::kill (pid, sig);
 
   if (status < 0)
-    {
-      using namespace std;
-      msg = ::strerror (errno);
-    }
+    msg = gnulib::strerror (errno);
 #else
   msg = NOT_SUPPORTED ("kill");
 #endif
@@ -394,20 +333,20 @@ octave_syscalls::popen2 (const std::string& cmd, const string_vector& args,
             msg = "popen2: process creation failed -- " + msg;
           else if (pid == 0)
             {
-	      std::string child_msg;
+              std::string child_msg;
 
-	      interactive = false;
+              interactive = false;
 
               // Child process
-              ::close (child_stdin[1]);
-              ::close (child_stdout[0]);
+              gnulib::close (child_stdin[1]);
+              gnulib::close (child_stdout[0]);
 
               if (dup2 (child_stdin[0], STDIN_FILENO) >= 0)
                 {
-                  ::close (child_stdin[0]);
+                  gnulib::close (child_stdin[0]);
                   if (dup2 (child_stdout[1], STDOUT_FILENO) >= 0)
                     {
-                      ::close (child_stdout[1]);
+                      gnulib::close (child_stdout[1]);
                       if (execvp (cmd, args, child_msg) < 0)
                         child_msg = "popen2 (child): unable to start process -- " + child_msg;
                     }
@@ -416,18 +355,19 @@ octave_syscalls::popen2 (const std::string& cmd, const string_vector& args,
                 }
               else
                 child_msg = "popen2 (child): file handle duplication failed -- " + child_msg;
-	      
-	      (*current_liboctave_error_handler)(child_msg.c_str());
-	      
-	      exit(0);
+
+              (*current_liboctave_error_handler)(child_msg.c_str());
+
+              exit(0);
             }
           else
             {
               // Parent process
-              ::close (child_stdin[0]);
-              ::close (child_stdout[1]);
+              gnulib::close (child_stdin[0]);
+              gnulib::close (child_stdout[1]);
+
 #if defined (F_SETFL) && defined (O_NONBLOCK)
-              if (! sync_mode && fcntl (child_stdout[0], F_SETFL, O_NONBLOCK, msg) < 0)
+              if (! sync_mode && octave_fcntl (child_stdout[0], F_SETFL, O_NONBLOCK, msg) < 0)
                 msg = "popen2: error setting file mode -- " + msg;
               else
 #endif
@@ -437,13 +377,14 @@ octave_syscalls::popen2 (const std::string& cmd, const string_vector& args,
                   return pid;
                 }
             }
-          ::close (child_stdout[0]);
-          ::close (child_stdout[1]);
+          gnulib::close (child_stdout[0]);
+          gnulib::close (child_stdout[1]);
         }
       else
         msg = "popen2: pipe creation failed -- " + msg;
-      ::close (child_stdin[0]);
-      ::close (child_stdin[1]);
+
+      gnulib::close (child_stdin[0]);
+      gnulib::close (child_stdin[1]);
     }
   else
     msg = "popen2: pipe creation failed -- " + msg;
@@ -452,8 +393,24 @@ octave_syscalls::popen2 (const std::string& cmd, const string_vector& args,
 #endif
 }
 
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
+int
+octave_fcntl (int fd, int cmd, long arg)
+{
+  std::string msg;
+  return octave_fcntl (fd, cmd, arg, msg);
+}
+
+int
+octave_fcntl (int fd, int cmd, long arg, std::string& msg)
+{
+  msg = std::string ();
+
+  int status = -1;
+
+  status = gnulib::fcntl (fd, cmd, arg);
+
+  if (status < 0)
+    msg = gnulib::strerror (errno);
+
+  return status;
+}
