@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006, 2007 John W. Eaton
+Copyright (C) 2006-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -25,8 +25,6 @@ along with Octave; see the file COPYING.  If not, see
 
 #ifndef _RANDGAMMA_H
 
-#include "oct-types.h"
-
 #ifdef  __cplusplus
 extern "C" {
 #endif
@@ -38,9 +36,3 @@ extern void oct_fill_randg (double a, octave_idx_type n, double *p);
 }
 #endif
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C ***
-;;; End: ***
-*/
