@@ -1,11 +1,11 @@
-## Copyright (C) 1996, 1997 John W. Eaton
+## Copyright (C) 1994-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,23 +13,33 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-## 02111-1307, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Mapping Function} {} csch (@var{x})
 ## Compute the hyperbolic cosecant of each element of @var{x}.
+## @seealso{acsch}
 ## @end deftypefn
 
 ## Author: jwe
 
-function w = csch (z)
+function y = csch (x)
 
   if (nargin != 1)
-    usage ("csch (z)");
+    print_usage ();
   endif
 
-  w = 1 ./ sinh(z);
+  y = 1 ./ sinh(x);
 
 endfunction
+
+%!test
+%! x = [pi/2*i, 3*pi/2*i];
+%! v = [-i, i];
+%! assert(all (abs (csch (x) - v) < sqrt (eps)));
+
+%!error csch ();
+
+%!error csch (1, 2);
+
