@@ -1,4 +1,4 @@
-## Copyright (C) 2008, 2009 David Bateman
+## Copyright (C) 2008-2011 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -30,7 +30,7 @@ function map = contrast (x, n)
     n = rows (colormap);
   elseif (nargin == 2)
     if (! isscalar (n))
-      error ("contrast: n must be a scalar");
+      error ("contrast: N must be a scalar");
     endif
   else
     print_usage ();
