@@ -1,4 +1,4 @@
-## Copyright (C) 1999, 2000, 2007, 2009 Kai Habel
+## Copyright (C) 1999-2011 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,32 +17,33 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} spring (@var{n})
-## Create color colormap.  This colormap is magenta to yellow.
-## The argument @var{n} should be a scalar.  If it
-## is omitted, the length of the current colormap or 64 is assumed.
+## @deftypefn  {Function File} {@var{map} =} spring ()
+## @deftypefnx {Function File} {@var{map} =} spring (@var{n})
+## Create color colormap.  This colormap varies from magenta to yellow.
+## The argument @var{n} must be a scalar.
+## If unspecified, the length of the current colormap, or 64, is used.
 ## @seealso{colormap}
 ## @end deftypefn
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-function map = spring (number)
+function map = spring (n)
 
   if (nargin == 0)
-    number = rows (colormap);
+    n = rows (colormap);
   elseif (nargin == 1)
-    if (! isscalar (number))
+    if (! isscalar (n))
       error ("spring: argument must be a scalar");
     endif
   else
     print_usage ();
   endif
 
-  if (number == 1)
-    map = [1, 0, 1];  
-  elseif (number > 1)
-    r = ones (number, 1);
-    g = (0:number - 1)' ./ (number - 1);
+  if (n == 1)
+    map = [1, 0, 1];
+  elseif (n > 1)
+    r = ones (n, 1);
+    g = (0:n - 1)' ./ (n - 1);
     b = 1 - g;
     map = [r, g, b];
   else
@@ -50,3 +51,10 @@ function map = spring (number)
   endif
 
 endfunction
+
+%!demo
+%! ## Show the 'spring' colormap as an image
+%! image (1:64, linspace (0, 1, 64), repmat (1:64, 64, 1)')
+%! axis ([1, 64, 0, 1], "ticy", "xy")
+%! colormap (spring (64))
+
