@@ -1,5 +1,4 @@
-## Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2005, 2006, 2007, 2008
-##               John W. Eaton
+## Copyright (C) 1993-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,26 +17,36 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} trace (@var{a})
-## Compute the trace of @var{a}, @code{sum (diag (@var{a}))}.
+## @deftypefn {Function File} {} trace (@var{A})
+## Compute the trace of @var{A}, @code{sum (diag (@var{A}))}.
 ## @end deftypefn
 
 ## Author: jwe
 
-function y = trace (x)
+function y = trace (A)
 
   if (nargin != 1)
     print_usage ();
   endif
 
-  if (ndims (x) > 2)
+  if (ndims (A) > 2)
     error ("trace: only valid on 2-D objects");
-  elseif (isempty (x))
+  elseif (isempty (A))
     y = 0;
-  elseif (any (size (x) == 1))
-    y = x(1);
+  elseif (any (size (A) == 1))
+    y = A(1);
   else
-    y = sum (diag (x));
+    y = sum (diag (A));
   endif
 
 endfunction
+
+%!assert(trace ([1, 2; 3, 4]) == 5);
+%!assert(trace ([1, 2; 3, 4; 5, 6]) == 5);
+%!assert(trace ([1, 3, 5; 2, 4, 6]) == 5);
+%!assert(trace ([]), 0);
+%!assert(trace (randn(1,0)), 0);
+%!
+%!error trace ();
+%!error trace (1, 2);
+%!error <only valid on 2-D objects> trace(reshape(1:9,[1,3,3]));
