@@ -1,4 +1,4 @@
-## Copyright (C) 2003, 2005, 2007, 2008 John W. Eaton
+## Copyright (C) 2003-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -29,7 +29,7 @@ function dirname = tempdir ()
   endif
 
   if (! strcmp (dirname(end), filesep))
-    cstrcat (dirname, filesep);
+    dirname = cstrcat (dirname, filesep);
   endif
 
   if (! isdir (dirname))
