@@ -1,5 +1,4 @@
-## Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2000, 2002, 2004,
-##               2005, 2006, 2007, 2008, 2009 John W. Eaton
+## Copyright (C) 1993-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} bar (@var{x}, @var{y})
+## @deftypefn  {Function File} {} bar (@var{x}, @var{y})
 ## @deftypefnx {Function File} {} bar (@var{y})
 ## @deftypefnx {Function File} {} bar (@var{x}, @var{y}, @var{w})
 ## @deftypefnx {Function File} {} bar (@var{x}, @var{y}, @var{w}, @var{style})
@@ -26,10 +25,10 @@
 ## @deftypefnx {Function File} {} bar (@var{h}, @dots{})
 ## Produce a bar graph from two vectors of x-y data.
 ##
-## If only one argument is given, it is taken as a vector of y-values
+## If only one argument is given, @var{y}, it is taken as a vector of y-values
 ## and the x coordinates are taken to be the indices of the elements.
 ##
-## The default width of 0.8 for the bars can be changed using @var{w}. 
+## The default width of 0.8 for the bars can be changed using @var{w}.
 ##
 ## If @var{y} is a matrix, then each column of @var{y} is taken to be a
 ## separate bar graph plotted on the same graph.  By default the columns
@@ -41,7 +40,7 @@
 ## object with one handle per column of the variable @var{y}.  This
 ## series allows common elements of the group of bar series objects to
 ## be changed in a single bar series and the same properties are changed
-## in the other "bar series".  For example
+## in the other "bar series".  For example,
 ##
 ## @example
 ## @group
@@ -54,10 +53,38 @@
 ## changes the position on the base of all of the bar series.
 ##
 ## The optional input handle @var{h} allows an axis handle to be passed.
-## Properties of the patch graphics object can be changed using
-## @var{prop}, @var{val} pairs.
 ##
-## @seealso{barh, plot} 
+## The bar graph's appearance may be modified by specifying property/value
+## pairs.  The following example modifies the face and edge colors.
+##
+## @example
+## bar (randn (1, 100), "facecolor", "r", "edgecolor", "b")
+## @end example
+##
+## @noindent
+## The color of the bars is taken from the figure's colormap, such that
+##
+## @example
+## @group
+## bar (rand(10,3))
+## colormap (summer ())
+## @end group
+## @end example
+##
+## @noindent
+## will change the colors used for the bars.  The color of bars can also be set
+## manually using the "facecolor" property as shown below.
+##
+## @example
+## @group
+## h = bar (rand(10,3))
+## set (h(1), "facecolor", "r")
+## set (h(2), "facecolor", "g")
+## set (h(3), "facecolor", "b")
+## @end group
+## @end example
+##
+## @seealso{barh, plot}
 ## @end deftypefn
 
 ## Author: jwe
