@@ -1,4 +1,4 @@
-## Copyright (C) 2008, 2009 David Bateman
+## Copyright (C) 2008-2011 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} plotmatrix (@var{x}, @var{y})
+## @deftypefn  {Function File} {} plotmatrix (@var{x}, @var{y})
 ## @deftypefnx {Function File} {} plotmatrix (@var{x})
 ## @deftypefnx {Function File} {} plotmatrix (@dots{}, @var{style})
 ## @deftypefnx {Function File} {} plotmatrix (@var{h}, @dots{})
@@ -30,7 +30,7 @@
 ## plot (@var{x} (:, i), @var{y} (:, j)
 ## @end example
 ##
-## Given a single argument @var{x}, then this is equivalent to 
+## Given a single argument @var{x}, then this is equivalent to
 ##
 ## @example
 ## plotmatrix (@var{x}, @var{x})
@@ -40,7 +40,7 @@
 ## except that the diagonal of the set of axes will be replaced with the
 ## histogram @code{hist (@var{x} (:, i))}.
 ##
-## The marker to use can be changed with the @var{style} argument, that is a 
+## The marker to use can be changed with the @var{style} argument, that is a
 ## string defining a marker in the same manner as the @code{plot}
 ## command.  If a leading axes handle @var{h} is passed to
 ## @code{plotmatrix}, then this axis will be used for the plot.
@@ -48,7 +48,7 @@
 ## The optional return value @var{h} provides handles to the individual
 ## graphics objects in the scatter plots, whereas @var{ax} returns the
 ## handles to the scatter plot axis objects.  @var{bigax} is a hidden
-## axis object that surrounds the other axes, such that the commands 
+## axis object that surrounds the other axes, such that the commands
 ## @code{xlabel}, @code{title}, etc., will be associated with this hidden
 ## axis.  Finally @var{p} returns the graphics objects associated with
 ## the histogram and @var{pax} the corresponding axes objects.
@@ -74,20 +74,20 @@ function [h, ax, bigax, p, pax] = plotmatrix (varargin)
       newplot ();
       [h2, ax2, p2, pax2, need_usage] = __plotmatrix__ (bigax2, varargin{:});
       if (need_usage)
-	print_usage ();
+        print_usage ();
       endif
       if (nargout > 0)
-	h = h2;
-	ax = ax2;
-	bigax = bigax2;
-	p = p2;
-	pax = pax2;
+        h = h2;
+        ax = ax2;
+        bigax = bigax2;
+        p = p2;
+        pax = pax2;
       endif
       axes (bigax2);
-      ctext = text (0, 0, "", "visible", "off", 
-		    "handlevisibility", "off", "xliminclude", "off",  
-		    "yliminclude", "off", "zliminclude", "off",
-		    "deletefcn", {@plotmatrixdelete, [ax2; pax2]});
+      ctext = text (0, 0, "", "visible", "off",
+                    "handlevisibility", "off", "xliminclude", "off",
+                    "yliminclude", "off", "zliminclude", "off",
+                    "deletefcn", {@plotmatrixdelete, [ax2; pax2]});
       set (bigax2, "visible", "off");
     unwind_protect_cleanup
       axes (oldh);
@@ -101,12 +101,12 @@ endfunction
 function plotmatrixdelete (h, d, ax)
   for i = 1 : numel (ax)
     hc = ax(i);
-    if (ishandle (hc) && strcmp (get (hc, "type"), "axes") && 
-	strcmpi (get (hc, "beingdeleted"), "off"))
+    if (ishandle (hc) && strcmp (get (hc, "type"), "axes")
+        && strcmpi (get (hc, "beingdeleted"), "off"))
       parent = get (hc, "parent");
       ## If the parent is invalid or being deleted, then do nothing
       if (ishandle (parent) && strcmpi (get (parent, "beingdeleted"), "off"))
-	delete (hc);
+        delete (hc);
       endif
     endif
   endfor
@@ -122,14 +122,14 @@ function [h, ax, p, pax, need_usage] = __plotmatrix__ (bigax, varargin)
     if (ischar (arg) || iscell (arg))
       [linespec, valid] = __pltopt__ ("plotmatrix", varargin{i}, false);
       if (valid)
-	have_line_spec = true;      
-	linespec = varargin(i);
-	varargin(i) = [];
-	nargin = nargin - 1;
-	break;
+        have_line_spec = true;
+        linespec = varargin(i);
+        varargin(i) = [];
+        nargin = nargin - 1;
+        break;
       else
-	need_usage = true;
-	returm;
+        need_usage = true;
+        returm;
       endif
     endif
   endfor
@@ -169,20 +169,20 @@ function [h, ax, p, pax, need_usage] = __plotmatrix__ (bigax, varargin)
     for j = 1 : m
       pos = [xsize * (j - 1) + xoff, ysize * (n - i) + yoff, xsize, ysize];
       tmp = axes ("outerposition", pos, "position", pos + border,
-		  "parent", parent);
+                  "parent", parent);
       if (i == j && have_hist)
-	pax = [pax ; tmp];
-	[nn, xx] = hist (X(:, i));
-	tmp = bar (xx, nn, 1.0);
-	p = [p; tmp];
+        pax = [pax ; tmp];
+        [nn, xx] = hist (X(:, i));
+        tmp = bar (xx, nn, 1.0);
+        p = [p; tmp];
       else
-	ax = [ax ; tmp];
-	if (have_line_spec)
-	  tmp = plot (X (:, i), Y (:, j), linespec);
-	else
-	  tmp = plot (X (:, i), Y (:, j), ".");
-	endif
-	h = [h ; tmp];
+        ax = [ax ; tmp];
+        if (have_line_spec)
+          tmp = plot (X (:, i), Y (:, j), linespec);
+        else
+          tmp = plot (X (:, i), Y (:, j), ".");
+        endif
+        h = [h ; tmp];
       endif
     endfor
   endfor
