@@ -1,5 +1,5 @@
-## Copyright (C) 2008, 2009 Jaroslav Hajek
-## Copyright (C) 2000, 2006, 2007 Paul Kienzle
+## Copyright (C) 2008-2011 Jaroslav Hajek
+## Copyright (C) 2000, 2006-2007 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -18,18 +18,20 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} setxor (@var{a}, @var{b})
+## @deftypefn  {Function File} {} setxor (@var{a}, @var{b})
 ## @deftypefnx {Function File} {} setxor (@var{a}, @var{b}, 'rows')
 ##
 ## Return the elements exclusive to @var{a} or @var{b}, sorted in ascending
 ## order.  If @var{a} and @var{b} are both column vectors return a column
 ## vector, otherwise return a row vector.
+## @var{a}, @var{b} may be cell arrays of string(s).
 ##
 ## @deftypefnx {Function File} {[@var{c}, @var{ia}, @var{ib}] =} setxor (@var{a}, @var{b})
 ##
-## Return index vectors @var{ia} and @var{ib} such that @code{a == c(ia)} and
-## @code{b == c(ib)}.
-## 
+## Return index vectors @var{ia} and @var{ib} such that @code{a(ia)} and
+## @code{b(ib)} are
+## disjoint sets whose union is @var{c}.
+##
 ## @seealso{unique, union, intersect, setdiff, ismember}
 ## @end deftypefn
 
@@ -39,9 +41,7 @@ function [c, ia, ib] = setxor (a, b, varargin)
     print_usage ();
   endif
 
-  if (nargin == 3 && ! strcmpi (varargin{1}, "rows"))
-    error ("setxor: if a third input argument is present, it must be the string 'rows'");
-  endif
+  [a, b] = validargs ("setxor", a, b, varargin{:});
 
   ## Form A and B into sets.
   if (nargout > 1)
@@ -64,24 +64,24 @@ function [c, ia, ib] = setxor (a, b, varargin)
       n = rows (c);
       idx = find (all (c(1:n-1) == c(2:n), 2));
       if (! isempty (idx))
-	c([idx, idx+1],:) = [];
-	i([idx, idx+1],:) = [];
+        c([idx, idx+1],:) = [];
+        i([idx, idx+1],:) = [];
       endif
     else
       na = numel (a); nb = numel (b);
       [c, i] = sort ([a(:); b(:)]);
       n = length (c);
       if (iscell (c))
-        idx = find (strcmp (c(1:n-1), c(2:n)));	  
+        idx = find (strcmp (c(1:n-1), c(2:n)));
       else
         idx = find (c(1:n-1) == c(2:n));
       endif
       if (! isempty (idx))
-	c([idx, idx+1]) = [];
-	i([idx, idx+1]) = [];
+        c([idx, idx+1]) = [];
+        i([idx, idx+1]) = [];
       endif
       if (size (a, 1) == 1 || size (b, 1) == 1)
-	c = c.';
+        c = c.';
       endif
     endif
   endif
@@ -93,8 +93,10 @@ function [c, ia, ib] = setxor (a, b, varargin)
 endfunction
 
 %!assert(setxor([1,2,3],[2,3,4]),[1,4])
+%!assert(setxor({'a'}, {'a', 'b'}), {'b'});
 %!test
 %! a = [3, 1, 4, 1, 5]; b = [1, 2, 3, 4];
 %! [y, ia, ib] = setxor (a, b.');
 %! assert(y, [2, 5]);
 %! assert(y, sort([a(ia), b(ib)]));
+
