@@ -1,11 +1,11 @@
-## Copyright (C) 1995, 1996, 1997  Kurt Hornik
+## Copyright (C) 1995-2011 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{p}, @var{y}] =} ppplot (@var{x}, @var{dist}, @var{params})
@@ -54,7 +53,7 @@ function [p, y] = ppplot (x, dist, varargin)
   endif
 
   if (! isvector (x))
-    error ("ppplot: x must be a vector");
+    error ("ppplot: X must be a vector");
   endif
 
   s = sort (x);
@@ -63,7 +62,7 @@ function [p, y] = ppplot (x, dist, varargin)
   if (nargin == 1)
     F = @stdnormal_cdf;
   else
-    F = str2func (sprintf ("%s_cdf", dist));
+    F = str2func (sprintf ("%scdf", dist));
   endif;
   if (nargin <= 2)
     y = feval (F, s);
@@ -77,3 +76,8 @@ function [p, y] = ppplot (x, dist, varargin)
   endif
 
 endfunction
+
+%% Test input validation
+%!error ppplot ();
+%!error ppplot (ones(2,2));
+
