@@ -1,11 +1,11 @@
-## Copyright (C) 1995, 1996, 1997  Kurt Hornik
+## Copyright (C) 1995-2011 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} normpdf (@var{x}, @var{m}, @var{s})
@@ -43,7 +42,7 @@ function pdf = normpdf (x, m, s)
   if (!isscalar (m) || !isscalar (s))
     [retval, x, m, s] = common_size (x, m, s);
     if (retval > 0)
-      error ("normpdf: x, m and s must be of common size or scalars");
+      error ("normpdf: X, M and S must be of common size or scalars");
     endif
   endif
 
@@ -52,7 +51,7 @@ function pdf = normpdf (x, m, s)
 
   if (isscalar (m) && isscalar (s))
     if (find (isinf (m) | isnan (m) | !(s >= 0) | !(s < Inf)))
-      pdf = NaN * ones (sz);
+      pdf = NaN (sz);
     else
       pdf = stdnormal_pdf ((x - m) ./ s) ./ s;
     endif
