@@ -1,4 +1,4 @@
-## Copyright (C) 2000, 2006, 2007, 2008, 2009 Paul Kienzle
+## Copyright (C) 2000-2011 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -17,14 +17,15 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} demo ('@var{name}',@var{n})
+## @deftypefn  {Command} {} demo @var{name} @var{n}
+## @deftypefnx {Function File} {} demo ('@var{name}', @var{n})
 ##
-## Runs any examples associated with the function '@var{name}'.  
-## Examples are stored in the script file, or in a file with the same 
-## name but no extension somewhere on your path.  To keep them separate 
+## Runs any examples associated with the function '@var{name}'.
+## Examples are stored in the script file, or in a file with the same
+## name but no extension somewhere on your path.  To keep them separate
 ## from the usual script code, all lines are prefixed by @code{%!}.  Each
 ## example is introduced by the keyword 'demo' flush left to the prefix,
-## with no intervening spaces.  The remainder of the example can contain 
+## with no intervening spaces.  The remainder of the example can contain
 ## arbitrary Octave code.  For example:
 ##
 ## @example
@@ -50,6 +51,7 @@
 ##    %! input("Press <enter> to continue: ","s");
 ## @end example
 ##
+## @noindent
 ## between the sections, but this is discouraged.  Other techniques
 ## include using multiple plots by saying figure between each, or
 ## using subplot to put multiple plots in the same window.
@@ -59,7 +61,7 @@
 ## use @code{eval(example('function',n))} to see them.  Because eval only
 ## evaluates one line, or one statement if the statement crosses
 ## multiple lines, you must wrap your demo in "if 1 <demo stuff> endif"
-## with the 'if' on the same line as 'demo'.  For example,
+## with the 'if' on the same line as 'demo'.  For example:
 ##
 ## @example
 ## @group
@@ -86,7 +88,9 @@ function demo (name, n)
 
   if (nargin < 2)
     n = 0;
-  endif
+  elseif (strcmp ("char", class (n)))
+    n = str2double (n);
+  endif 
 
   [code, idx] = test (name, "grabdemo");
   if (length (idx) == 0)
@@ -119,7 +123,7 @@ function demo (name, n)
       __demo__;
     catch
       ## Let the programmer know which demo failed.
-      printf ("%s example %d: failed\n%s", name, doidx(i), __error_text__);
+      printf ("%s example %d: failed\n%s\n", name, doidx(i), __error_text__);
     end_try_catch
     clear __demo__;
   endfor
