@@ -159,7 +159,7 @@ function [a, b] = twoouts (x)\n\
 endfunction\n\
 [aa, bb] = cellfun(@@twoouts, @{1, 2, 3@})\n\
      @result{}\n\
-        aa = \n\
+        aa =\n\
            1 2 3\n\
         bb =\n\
            1 4 9\n\
@@ -214,7 +214,7 @@ cellfun (@@factorial, @{-1,2@},'ErrorHandler',@@foo)\n\
 
   if (nargin < 2)
     {
-      error ("cellfun: you must supply at least 2 arguments");
+      error ("cellfun: function requires at least 2 arguments");
       print_usage ();
       return retval;
     }
