@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 2004, 2005, 2007 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -69,10 +69,15 @@ along with Octave; see the file COPYING.  If not, see
 #include "ov-uint64.h"
 #include "ov-uint8.h"
 #include "ov-scalar.h"
+#include "ov-float.h"
 #include "ov-complex.h"
+#include "ov-flt-complex.h"
 #include "ov-re-mat.h"
+#include "ov-flt-re-mat.h"
 #include "ov-cx-mat.h"
+#include "ov-flt-cx-mat.h"
 #include "ov-typeinfo.h"
+#include "ov-null-mat.h"
 #include "ops.h"
 #include "xdiv.h"
 #include "xpow.h"
@@ -142,9 +147,3 @@ install_i32_i32_ops (void)
   OCTAVE_INSTALL_MIXED_INT_CMP_OPS (int32, int64);
   OCTAVE_INSTALL_MIXED_INT_CMP_OPS (int32, uint64);
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
