@@ -1,12 +1,14 @@
 /*
 
-Copyright (C) 2004 David Bateman
+Copyright (C) 2004-2011 David Bateman
 Copyright (C) 1998-2004 Andy Adler
 
+This file is part of Octave.
+
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -14,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -47,12 +48,12 @@ DEFBINOP_OP (mul, sparse_matrix, complex_matrix, *)
 
 DEFBINOP (div, sparse_matrix, complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, 
-		   const octave_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_matrix&);
   MatrixType typ = v2.matrix_type ();
-  
-  ComplexMatrix ret = xdiv (v1.matrix_value (), 
-			    v2.complex_matrix_value (), typ);
+
+  ComplexMatrix ret = xdiv (v1.matrix_value (),
+                            v2.complex_matrix_value (), typ);
 
   v2.matrix_type (typ);
   return ret;
@@ -73,7 +74,7 @@ DEFBINOP (ldiv, sparse_matrix, complex_matrix)
       double d = v1.scalar_value ();
 
       if (d == 0.0)
-	gripe_divide_by_zero ();
+        gripe_divide_by_zero ();
 
       return octave_value (v2.complex_array_value () / d);
     }
@@ -81,8 +82,8 @@ DEFBINOP (ldiv, sparse_matrix, complex_matrix)
     {
       MatrixType typ = v1.matrix_type ();
 
-      ComplexMatrix ret = xleftdiv (v1.sparse_matrix_value (), 
-				    v2.complex_matrix_value (), typ);
+      ComplexMatrix ret = xleftdiv (v1.sparse_matrix_value (),
+                                    v2.complex_matrix_value (), typ);
 
       v1.matrix_type (typ);
       return ret;
@@ -101,20 +102,20 @@ DEFBINOP_FN (el_div, sparse_matrix, complex_matrix, quotient)
 
 DEFBINOP (el_pow, sparse_matrix, complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, 
-		   const octave_complex_matrix&);
-  
-  return octave_value 
-    (elem_xpow (v1.sparse_matrix_value (), SparseComplexMatrix 
-		(v2.complex_matrix_value ())));
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_matrix&);
+
+  return octave_value
+    (elem_xpow (v1.sparse_matrix_value (), SparseComplexMatrix
+                (v2.complex_matrix_value ())));
 }
 
 DEFBINOP (el_ldiv, sparse_matrix, complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, 
-		   const octave_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_matrix&);
 
-  return octave_value 
+  return octave_value
     (quotient (v2.complex_matrix_value (), v1.sparse_matrix_value ()));
 }
 
@@ -149,30 +150,24 @@ install_sm_cm_ops (void)
   INSTALL_BINOP (op_ge, octave_sparse_matrix, octave_complex_matrix, ge);
   INSTALL_BINOP (op_gt, octave_sparse_matrix, octave_complex_matrix, gt);
   INSTALL_BINOP (op_ne, octave_sparse_matrix, octave_complex_matrix, ne);
-  INSTALL_BINOP (op_el_mul, octave_sparse_matrix, octave_complex_matrix, 
-		 el_mul);
-  INSTALL_BINOP (op_el_div, octave_sparse_matrix, octave_complex_matrix, 
-		 el_div);
-  INSTALL_BINOP (op_el_pow, octave_sparse_matrix, octave_complex_matrix, 
-		 el_pow);
-  INSTALL_BINOP (op_el_ldiv, octave_sparse_matrix, octave_complex_matrix, 
-		 el_ldiv);
-  INSTALL_BINOP (op_el_and, octave_sparse_matrix, octave_complex_matrix, 
-		 el_and);
-  INSTALL_BINOP (op_el_or, octave_sparse_matrix, octave_complex_matrix, 
-		 el_or);
+  INSTALL_BINOP (op_el_mul, octave_sparse_matrix, octave_complex_matrix,
+                 el_mul);
+  INSTALL_BINOP (op_el_div, octave_sparse_matrix, octave_complex_matrix,
+                 el_div);
+  INSTALL_BINOP (op_el_pow, octave_sparse_matrix, octave_complex_matrix,
+                 el_pow);
+  INSTALL_BINOP (op_el_ldiv, octave_sparse_matrix, octave_complex_matrix,
+                 el_ldiv);
+  INSTALL_BINOP (op_el_and, octave_sparse_matrix, octave_complex_matrix,
+                 el_and);
+  INSTALL_BINOP (op_el_or, octave_sparse_matrix, octave_complex_matrix,
+                 el_or);
 
   INSTALL_CATOP (octave_sparse_matrix, octave_complex_matrix, sm_cm);
 
-  INSTALL_ASSIGNCONV (octave_sparse_matrix, octave_complex_matrix, 
-		      octave_sparse_complex_matrix);
+  INSTALL_ASSIGNCONV (octave_sparse_matrix, octave_complex_matrix,
+                      octave_sparse_complex_matrix);
 
-  INSTALL_WIDENOP (octave_sparse_matrix, octave_complex_matrix, 
-		   sparse_complex_matrix_conv);
+  INSTALL_WIDENOP (octave_sparse_matrix, octave_complex_matrix,
+                   sparse_complex_matrix_conv);
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
