@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1993-2011 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -36,9 +35,9 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 class octave_value;
 
-extern int octave_read (char *buf, unsigned max_size);
-extern FILE *get_input_from_file (const std::string& name, int warn = 1);
-extern FILE *get_input_from_stdin (void);
+extern OCTINTERP_API int octave_read (char *buf, unsigned max_size);
+extern OCTINTERP_API FILE *get_input_from_file (const std::string& name, int warn = 1);
+extern OCTINTERP_API FILE *get_input_from_stdin (void);
 
 // Global pointer for eval().
 extern std::string current_eval_string;
@@ -54,6 +53,9 @@ extern bool input_from_eval_string_pending;
 // the command line.
 extern bool input_from_command_line_file;
 
+// TRUE means that stdin is a terminal, not a pipe or redirected file.
+extern bool stdin_is_tty;
+
 // TRUE means we're parsing a function file.
 extern bool reading_fcn_file;
 
@@ -66,6 +68,9 @@ extern std::string curr_fcn_file_full_name;
 // TRUE means we're parsing a script file.
 extern bool reading_script_file;
 
+// TRUE means we're parsing a classdef file.
+extern bool reading_classdef_file;
+
 // If we are reading from an M-file, this is it.
 extern FILE *ff_instream;
 
@@ -84,6 +89,13 @@ extern std::string current_input_line;
 // TRUE after a call to completion_matches.
 extern bool octave_completion_matches_called;
 
+// TRUE if the plotting system has requested a call to drawnow at
+// the next user prompt.
+extern OCTINTERP_API bool Vdrawnow_requested;
+
+// TRUE if we are in debugging mode.
+extern OCTINTERP_API bool Vdebugging;
+
 extern std::string gnu_readline (const std::string& s, bool force_readline = false);
 
 extern void initialize_command_input (void);
@@ -94,6 +106,8 @@ extern octave_value do_keyboard (const octave_value_list& args = octave_value_li
 
 extern std::string VPS4;
 
+extern char Vfilemarker;
+
 enum echo_state
 {
   ECHO_OFF = 0,
@@ -107,9 +121,3 @@ extern int Vecho_executing_commands;
 extern octave_time Vlast_prompt_time;
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
